import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, Inject, InjectionToken, NgModule } from '@angular/core';
import * as i1 from '@angular/common/http';
import { ReplaySubject, BehaviorSubject } from 'rxjs';
import { tap, switchMap } from 'rxjs/operators';

class AccountService {
    constructor(environment, http) {
        this.environment = environment;
        this.http = http;
    }
    accounts(groupId) {
        return this.http.get(this.environment.backend + '/api/v1/groups/' + groupId + '/accounts');
    }
    account(groupId, accountId) {
        return this.http.get(this.environment.backend + '/api/v1/groups/' + groupId + '/accounts/' + accountId);
    }
    search(query) {
        return this.http.get(this.environment.backend + '/api/v1/accounts', { params: { query } });
    }
    createAccount(groupId, account) {
        return this.http.post(`${this.environment.backend}/api/v1/groups/${groupId}/accounts`, account);
    }
    updateAccount(groupId, accountId, account) {
        return this.http.put(`${this.environment.backend}/api/v1/groups/${groupId}/accounts/${accountId}`, account);
    }
    deleteAccount(groupId, accountId) {
        return this.http.delete(this.environment.backend + '/api/v1/groups/' + groupId + '/accounts/' + accountId);
    }
}
AccountService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AccountService, deps: [{ token: ENVIRONMENT }, { token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
AccountService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AccountService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AccountService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [ENVIRONMENT]
                }] }, { type: i1.HttpClient }]; } });

class AuthService {
    constructor(environment, http) {
        this.environment = environment;
        this.http = http;
    }
    getProviders() {
        return this.http.get(this.environment.backend + '/auth/providers');
    }
}
AuthService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AuthService, deps: [{ token: ENVIRONMENT }, { token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
AuthService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AuthService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AuthService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [ENVIRONMENT]
                }] }, { type: i1.HttpClient }]; } });

class GroupService {
    constructor(environment, http) {
        this.environment = environment;
        this.http = http;
    }
    groups() {
        return this.http.get(this.environment.backend + '/api/v1/groups');
    }
    createGroup(name, description) {
        return this.http.post(this.environment.backend + '/api/v1/groups', { name, description });
    }
    group(id) {
        return this.http.get(this.environment.backend + '/api/v1/groups/' + id);
    }
    updateGroup(id, name, description) {
        return this.http.put(this.environment.backend + '/api/v1/groups/' + id, { name, description });
    }
    deleteGroup(id) {
        return this.http.delete(this.environment.backend + '/api/v1/groups/' + id);
    }
}
GroupService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: GroupService, deps: [{ token: ENVIRONMENT }, { token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
GroupService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: GroupService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: GroupService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [ENVIRONMENT]
                }] }, { type: i1.HttpClient }]; } });

class JwtService {
    constructor() {
        this.currentJwtSubject = new ReplaySubject(1);
        this.currentTokenSubject = new ReplaySubject(1);
    }
    get currentJwt() {
        return this.currentJwtSubject.asObservable();
    }
    get currentToken() {
        return this.currentTokenSubject.asObservable();
    }
    setJwt(jwt) {
        this.currentJwtSubject.next(jwt);
    }
    setToken(token) {
        this.currentTokenSubject.next(token);
    }
}
JwtService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: JwtService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
JwtService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: JwtService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: JwtService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

var TokenType;
(function (TokenType) {
    TokenType["PasswordToken"] = "PasswordToken";
    TokenType["LoginToken"] = "LoginToken";
    TokenType["SessionToken"] = "SessionToken";
})(TokenType || (TokenType = {}));

class LoginService {
    constructor(environment, http, jwtService) {
        this.environment = environment;
        this.http = http;
        this.jwtService = jwtService;
        this.JWT_STORAGE_NAME = 'jwt_token';
        this.userSubject = new BehaviorSubject(null);
        this.initialize();
        this.jwtService.currentJwt.subscribe(jwt => {
            if (jwt !== null) {
                sessionStorage.setItem(this.JWT_STORAGE_NAME, jwt);
            }
        });
    }
    get user$() {
        return this.userSubject.asObservable();
    }
    initialize() {
        const jwt = sessionStorage.getItem(this.JWT_STORAGE_NAME);
        if (jwt) {
            this.jwtService.setJwt(jwt);
            this.info().subscribe();
        }
        else {
            this.jwtService.setJwt(null);
            this.jwtService.setToken(null);
        }
    }
    updateJwt(jwt) {
        this.jwtService.setJwt(jwt);
        return this.info();
    }
    login(password) {
        return this.http.post(this.environment.backend + '/api/v1/auth/login', { password }).pipe(tap(token => {
            this.updateJwt(token.token);
        }), switchMap(() => this.info()));
    }
    loginWithToken(token) {
        return this.http.post(this.environment.backend + '/api/v1/auth/login/token', { token: token.token }).pipe(tap(token => {
            this.updateJwt(token.token);
        }), switchMap(() => this.info()));
    }
    createLoginToken() {
        return this.http.get(this.environment.backend + '/api/v1/auth/token');
    }
    initialPassword(password) {
        return this.http.post(this.environment.backend + '/api/v1/auth/password', { password }).pipe(tap(token => {
            this.updateJwt(token.token);
        }), switchMap(() => this.info()));
    }
    updatePassword(currentPassword, newPassword) {
        return this.http.put(this.environment.backend + '/api/v1/auth/password', { currentPassword, newPassword });
    }
    info() {
        return this.http.get(this.environment.backend + '/api/v1/auth/info').pipe(tap(token => {
            this.jwtService.setToken(token);
            this.userSubject.next(token.tokenType == TokenType.SessionToken ? token?.user : null);
        }, (err) => { if (err)
            this.logout(); }));
    }
    logout() {
        this.jwtService.setJwt(null);
        this.jwtService.setToken(null);
        this.userSubject.next(null);
        sessionStorage.removeItem(this.JWT_STORAGE_NAME);
    }
}
LoginService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: LoginService, deps: [{ token: ENVIRONMENT }, { token: i1.HttpClient }, { token: JwtService }], target: i0.ɵɵFactoryTarget.Injectable });
LoginService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: LoginService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: LoginService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [ENVIRONMENT]
                }] }, { type: i1.HttpClient }, { type: JwtService }]; } });

class MemberService {
    constructor(environment, http) {
        this.environment = environment;
        this.http = http;
    }
    members(groupId) {
        return this.http.get(this.environment.backend + '/api/v1/groups/' + groupId + '/members');
    }
    addMember(groupId, memberId, role) {
        return this.http.post(this.environment.backend + '/api/v1/groups/' + groupId + '/members', { memberId, role });
    }
    updateMemberRole(groupId, memberId, role) {
        return this.http.put(this.environment.backend + '/api/v1/groups/' + groupId + '/members/' + memberId, { role });
    }
    removeMember(groupId, memberId) {
        return this.http.delete(this.environment.backend + '/api/v1/groups/' + groupId + '/members/' + memberId);
    }
}
MemberService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: MemberService, deps: [{ token: ENVIRONMENT }, { token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
MemberService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: MemberService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: MemberService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [ENVIRONMENT]
                }] }, { type: i1.HttpClient }]; } });

class UserService {
    constructor(environment, http) {
        this.environment = environment;
        this.http = http;
    }
    search(search) {
        return this.http.get(this.environment.backend + '/api/v1/users', { params: { search } });
    }
    current() {
        return this.http.get(this.environment.backend + '/api/v1/users/current');
    }
}
UserService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: UserService, deps: [{ token: ENVIRONMENT }, { token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
UserService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: UserService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: UserService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [ENVIRONMENT]
                }] }, { type: i1.HttpClient }]; } });

const ENVIRONMENT = new InjectionToken('environment');
class AccountTrackerLibModule {
    static forRoot(config) {
        return {
            ngModule: AccountTrackerLibModule,
            providers: [
                // providers
                config.environment,
                // services
                AccountService,
                AuthService,
                GroupService,
                JwtService,
                LoginService,
                MemberService,
                UserService
            ]
        };
    }
}
AccountTrackerLibModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AccountTrackerLibModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AccountTrackerLibModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.1.2", ngImport: i0, type: AccountTrackerLibModule, imports: [CommonModule] });
AccountTrackerLibModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AccountTrackerLibModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: AccountTrackerLibModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule
                    ]
                }]
        }] });

var EntryType;
(function (EntryType) {
    EntryType["Text"] = "text";
    EntryType["Password"] = "password";
    EntryType["Multiline"] = "multiline";
    EntryType["Url"] = "url";
    EntryType["FileHeader"] = "file-header";
    EntryType["FileContent"] = "file-content";
})(EntryType || (EntryType = {}));

class FormConfigService {
    createGroupConfig(name, description) {
        return {
            entries: [{
                    title: 'Name',
                    value: name,
                    name: 'name',
                    required: true,
                    type: EntryType.Text,
                }, {
                    title: 'Description',
                    value: description,
                    name: 'description',
                    required: true,
                    type: EntryType.Multiline,
                }]
        };
    }
    mapToAccount(config, value) {
        return {
            name: value.name,
            description: value.description,
            entries: this.mapFormEntry(config.entries.slice(2), value)
        };
    }
    mapFromAccount(account, addHeader) {
        if (addHeader) {
            return {
                entries: [{
                        title: 'Name',
                        value: account.name,
                        name: 'name',
                        required: true,
                        type: EntryType.Text,
                    }, {
                        title: 'Description',
                        value: account.description,
                        name: 'description',
                        required: true,
                        type: EntryType.Multiline
                    }, ...this.mapAccountEntry(account.entries)]
            };
        }
        else {
            return {
                entries: this.mapAccountEntry(account.entries)
            };
        }
    }
    mapAccountEntry(entries) {
        return entries.map(e => {
            return {
                title: e.key[0].toUpperCase() + e.key.substring(1),
                name: e.key,
                type: e.type,
                required: true,
                value: e.value
            };
        });
    }
    mapFormEntry(entries, value) {
        return entries.map(entry => ({
            key: entry.name,
            value: value[entry.name],
            type: entry.type,
        }));
    }
}
FormConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: FormConfigService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
FormConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: FormConfigService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: FormConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class Template {
    getConfig() {
        return {
            entries: [{
                    title: 'Name',
                    name: 'name',
                    type: EntryType.Text,
                    required: true,
                    value: null
                }, {
                    title: 'Description',
                    name: 'description',
                    type: EntryType.Multiline,
                    required: true,
                    value: null
                }, ...this.getFields()]
        };
    }
}
class WebAccountTemplate extends Template {
    name() {
        return "Web account";
    }
    getFields() {
        return [{
                title: 'Url',
                name: 'url',
                type: EntryType.Url,
                required: true,
                value: null
            }, {
                title: 'Username',
                name: 'username',
                type: EntryType.Text,
                required: true,
                value: null
            }, {
                title: 'Password',
                name: 'password',
                type: EntryType.Password,
                required: true,
                value: ''
            }];
    }
}
class AccountTemplate extends Template {
    name() {
        return "Account";
    }
    getFields() {
        return [{
                title: 'Username',
                name: 'username',
                type: EntryType.Text,
                required: true,
                value: null
            }, {
                title: 'Password',
                name: 'password',
                type: EntryType.Password,
                required: true,
                value: ''
            }];
    }
}
class FileTemplate extends Template {
    name() {
        return "File";
    }
    getFields() {
        return [{
                title: 'Filename',
                name: 'filename',
                type: EntryType.FileHeader,
                required: true,
                value: null
            }, {
                title: 'Content',
                name: 'content',
                type: EntryType.FileContent,
                required: true,
                value: null
            }];
    }
}
class EnvironmentConfigTemplate extends Template {
    name() {
        return "Environment config";
    }
    getFields() {
        return [{
                title: 'Filename',
                name: 'filename',
                type: EntryType.Text,
                required: true,
                value: null
            }, {
                title: 'Content',
                name: 'content',
                type: EntryType.Multiline,
                required: true,
                value: ''
            }];
    }
}

class TemplateService {
    constructor() {
        this.templates = [
            new WebAccountTemplate(),
            new AccountTemplate(),
            new EnvironmentConfigTemplate(),
            new FileTemplate()
        ];
    }
    getAvailableTemplates() {
        return this.templates.map(t => t.name());
    }
    createAccountConfig(template) {
        return this.templates.filter(t => t.name() === template)[0].getConfig();
    }
}
TemplateService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: TemplateService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
TemplateService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: TemplateService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: TemplateService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class PasswordGeneratorService {
    constructor() {
        this.lowercase = 'abcdefghijklmnopqrstuvwxyz';
        this.uppercase = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
        this.symbols = '!#$%&/()=?*+;,:.-_><';
        this.numbers = '0123456789';
    }
    generatePassword(config) {
        let value = (config.lowercase ? this.lowercase : '') +
            (config.uppercase ? this.uppercase : '') +
            (config.symbols ? this.symbols : '') +
            (config.numbers ? this.numbers : '');
        if (value === '') {
            value = this.lowercase + this.uppercase + this.numbers;
        }
        const array = new Uint16Array(config.size);
        window.crypto.getRandomValues(array);
        let password = '';
        for (const val of array) {
            password += value[val % value.length];
        }
        return password;
    }
}
PasswordGeneratorService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: PasswordGeneratorService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
PasswordGeneratorService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: PasswordGeneratorService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.2", ngImport: i0, type: PasswordGeneratorService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

var MemberRole;
(function (MemberRole) {
    MemberRole["ADMIN"] = "ADMIN";
    MemberRole["EDITOR"] = "EDITOR";
    MemberRole["VIEWER"] = "VIEWER";
})(MemberRole || (MemberRole = {}));

/*
 * Public API Surface of account-tracker-lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AccountService, AccountTemplate, AccountTrackerLibModule, AuthService, ENVIRONMENT, EntryType, EnvironmentConfigTemplate, FileTemplate, FormConfigService, GroupService, JwtService, LoginService, MemberRole, MemberService, PasswordGeneratorService, Template, TemplateService, TokenType, UserService, WebAccountTemplate };
//# sourceMappingURL=bbr-dev-account-tracker-lib.mjs.map
